//Copyright 2005 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.

package mmsmidlet;

import javax.microedition.lcdui.*;
import javax.wireless.messaging.*;

// Form used to display the contents of a received message
class ReceiveScreen
  extends Form
  implements CommandListener {
  private String[] connections;
  private final MMSMIDlet midlet;
  private final Command commandClose =
    new Command("Close", Command.ITEM, 1);
  
  ReceiveScreen(MMSMIDlet midlet) {
    super(null);
    this.midlet = midlet;
  } 
  
  public void setMessage(Message mmsMessage)  {
    if (mmsMessage != null) {
      createForm(mmsMessage);
    }
  }  
   
  public void commandAction(Command c, Displayable d) {
    if (c==commandClose) {
      midlet.resumeDisplay();
    }
  }
  
  private void createForm(Message mmsMessage) {
    deleteAll();  
    setTitle("Received MMS Message");
  
    if (mmsMessage instanceof MultipartMessage) {
      MultipartMessage  multipartMessage =
        (MultipartMessage) mmsMessage;
  
      // Display message header.
      StringItem messageHeader = new StringItem(null,
          "From: " + mmsMessage.getAddress() + "\n" +
          "Sent: " + multipartMessage.getTimestamp().toString());
      messageHeader.setLayout(Item.LAYOUT_NEWLINE_AFTER);
      append(messageHeader);
  
      MessagePart[] messageParts = multipartMessage.getMessageParts();
  
      // Display all parts of the message.
      for (int i = 0; i < messageParts.length; i++) {
        MessagePart messagePart = messageParts[i];
        String mimeType = messagePart.getMIMEType();
        String contentLocation = messagePart.getContentLocation();
 
        byte[] part = messagePart.getContent();
  
        if (mimeType.equals("image/jpeg")) {
          // Message contains an image.
          Image image = Image.createImage(part, 0, part.length);
          ImageItem imageItem = new ImageItem(null,
              image,
              Item.LAYOUT_CENTER + Item.LAYOUT_NEWLINE_AFTER,
              contentLocation);
          append(imageItem);
        }
        if (mimeType.equals("text/plain")) {
          // Message contains text.
          StringItem stringItem = new StringItem(null,
              new String(part));
          stringItem.setLayout(Item.LAYOUT_CENTER);
          append(stringItem);
        }
        // Unknown MIME-types are ignored
      }
    }
  
    addCommand(commandClose);
    setCommandListener(this);
  }
}
