//Copyright 2005 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.

package mmsmidlet;

import java.io.*;
import javax.microedition.lcdui.*;
import javax.wireless.messaging.*;

// This form displays the content of the captured image
// and fields to add the recipient address and the
// text of the message
class SendScreen
  extends Form
  implements CommandListener {
  private final MMSMIDlet midlet;
  
  private final Command commandSend =
    new Command("Send", Command.ITEM, 1);
  private final Command commandBack =
    new Command("Back", Command.BACK, 0);
  
  private TextField messageText;
  private TextField recipientPhone;
  private byte[] messageImage; 
  
  SendScreen(MMSMIDlet midlet) {
  	super("MMS Message");
  	this.midlet = midlet;
  	addCommand(commandSend);
  	addCommand(commandBack);
  
  	setCommandListener(this);
  }  
  
  void initializeComposeCanvas(byte[] pngImage) {
    messageText = new TextField("Text: ",
        null,
        256,
        TextField.ANY);
    recipientPhone = new TextField("To: ",
        null,
        256,TextField.PHONENUMBER);
    messageImage = pngImage;
    Image tempImage = Image.createImage(pngImage,
        0,
        pngImage.length);
    ImageItem imageItem = new ImageItem(null,
        tempImage,
        Item.LAYOUT_CENTER,
        null);
 
    deleteAll();  	
  	append(messageText);
  	append(recipientPhone);
  	append(imageItem);
  
  	midlet.showSendScreen();
  }  
  
  public void commandAction(Command c, Displayable d) {
    if (c==commandBack) {
      midlet.showCameraScreen();
    }
  
    if (c==commandSend) {
      sendMMS();
    }
  }  
  
  private void sendMMS() {
    String recipientAddress = "mms://"
      + recipientPhone.getString() + ":"
      + midlet.getApplicationID();
  
    try {
      // get the byte content of the message and 
      // the captured image
      byte[] textBytes = messageText.getString()
        .getBytes("UTF-8");
      byte[] imageBytes = messageImage;
  
      // Create the message part containting the image
      // and give the appropriate MIME-type and id
      MessagePart imagePart= new MessagePart(imageBytes,
        0,
        imageBytes.length,
        "image/jpeg",
        "id0",
        "snapshot image",
        null);
  
        // Create the message part containting the text
        // and give the appropriate MIME-type and id
      MessagePart textPart= new MessagePart(textBytes,
        0,
        textBytes.length,
        "text/plain",
        "id1",
        "message text",
        "UTF-8");
  
      midlet.showInfo("Sending message...");
      midlet.sendMessage(recipientAddress, imagePart, textPart);
    } catch (UnsupportedEncodingException uee) {
  	  midlet.showError("Encoding not supported. "
          + uee.getMessage());
  	} catch (SizeExceededException see) {
  	  midlet.showError("Message part is too big. "
  	      + see.getMessage());
  	}
  }
}
